package com.younike.hlpay.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.younike.common.utils.StringUtils;
import com.younike.hlpay.constant.AppPayType;
import com.younike.hlpay.constant.HeliPayContants;
import com.younike.hlpay.constant.PayType;
import com.younike.hlpay.dto.*;
import com.younike.hlpay.service.IPayService;
import com.younike.hlpay.util.BeanUtils;
import com.younike.hlpay.util.Disguiser;
import com.younike.hlpay.util.HttpClientService;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.httpclient.HttpStatus;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.beans.IntrospectionException;
import java.lang.reflect.InvocationTargetException;
import java.math.BigDecimal;
import java.util.*;

import static com.younike.hlpay.constant.HeliPayContants.*;

/**
 * @author chenpengfei
 */
@Service
@Log4j2
public class PayServiceImpl implements IPayService {

    @Value("${hlb.wechat.xcx.cbUrl}")
    private String hlbCbUrl;

    @Value("${hlb.wechat.xcx.scanCbUrl}")
    private String hlbScanPayCbUrl;

    @Value("${hlb.wechat.xcx.scanCbSuccessUrl}")
    private String hlbScanPayCbSuccessUrl;

    @Value("${hlb.wechat.xcx.appid}")
    private String hlbAppId;

    @Value("${hlb.refund.cbUrl}")
    private String refundCbUrl;


    @Override
    public Map<String, Object> wxAppletPay(PaymentParam paymentParam, BillInfo billInfo) {
        // 取消旧订单
//        cancelOrder(HLB_PAY_PREFIX_WX + paymentParam.getOrderId());
        // 微信小程序支付对象
        AppPayPublicCreateOrderVo payVo = new AppPayPublicCreateOrderVo();
        payVo.setP1_bizType("AppPayApplet");
        if(paymentParam.getAddType() == 0) {
            if (paymentParam.getModifyIndex() == null) {
                payVo.setP2_orderId(HLB_PAY_PREFIX_WX + paymentParam.getOrderId() );
            } else {
                payVo.setP2_orderId(HLB_PAY_PREFIX_WX + paymentParam.getOrderId() + HLB_MOD_PAY_SUFFIX + paymentParam.getModifyIndex());
            }
        }
        //追加
        if(paymentParam.getAddType() == 1) {
            payVo.setP2_orderId(HLB_PAY_PREFIX_WX + paymentParam.getOrderId() + HLB_ADD_PAY_SUFFIX + paymentParam.getAddCountIndex());
        }
        String customerNumber = MAIN_CUSTOMER_NUMBER;
        // 订单支付，分账
        payVo.setSplitBillType("FIXED_AMOUNT");
        // 分账规则串
        payVo.setRuleJson(billInfo.getSplitBillRule());

        // 营销补贴
        if (StringUtils.isNotEmpty(billInfo.getMarketingRuleStr())) {
            payVo.setP23MarketingRule(billInfo.getMarketingRuleStr());
        }
        payVo.setP12_notifyUrl(hlbCbUrl);
        payVo.setP3_customerNumber(customerNumber);
        payVo.setP4_payType(PayType.APPLET.name());
        payVo.setP5_appid(hlbAppId);
        payVo.setP6_deviceInfo("DEVICE");
        payVo.setP7_isRaw("1");
        payVo.setP8_openid(billInfo.getOpenId());
        payVo.setP9_orderAmount(billInfo.getOrderAmount().toString());
        payVo.setP10_currency("CNY");
        payVo.setP11_appType(AppPayType.WXPAY.name());
        payVo.setP14_orderIp("127.0.0.1");
        payVo.setP15_goodsName("优鲜信");
        Map<String, String> map = null;
        try {
            map = BeanUtils.convertBean(payVo, new LinkedHashMap());
        } catch (IntrospectionException e) {
            e.printStackTrace();
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        } catch (InvocationTargetException e) {
            e.printStackTrace();
        }
        String oriMessage = BeanUtils.getSignedByPresetParameter(map, AppPayPublicCreateOrderVo.NEED_SIGN_PARAMS);
        log.info("签名原文串：" + oriMessage);
        String sign = Disguiser.disguiseMD5(oriMessage.trim());
        log.info("签名串：" + sign);
        map.put("sign", sign);
        log.info("发送参数：" + map);
        Map<String, Object> resultMap = HttpClientService.getHttpResp(map, HeliPayContants.PAY_REQUEST_URL);
        return resultMap;
    }

    @Override
    public Map<String, Object> aliSdkPay(PaymentParam paymentParam, BillInfo billInfo) {
        // 取消旧订单
//        boolean b = cancelOrder(HLB_PAY_PREFIX_ALI + paymentParam.getOrderId());
//        log.info(b);
        // 微信小程序支付对象
        SDKCreateOrderVo payVo = new SDKCreateOrderVo();
        payVo.setP1_bizType("AppPay");
        String customerNumber = MAIN_CUSTOMER_NUMBER;
        // 判断业务类型
        // 订单支付，分账
        payVo.setSplitBillType("FIXED_AMOUNT");
        // 分账规则串
        payVo.setRuleJson(billInfo.getSplitBillRule());

        // 营销补贴
        if (StringUtils.isNotEmpty(billInfo.getMarketingRuleStr())) {
            payVo.setP18MarketingRule(billInfo.getMarketingRuleStr());
        }
        payVo.setP9_notifyUrl(hlbCbUrl);
        payVo.setP12_goodsName("家政服务订单");
        if (paymentParam.getAddType() == 0) {
            if (paymentParam.getModifyIndex() == null) {
                payVo.setP2_orderId(HLB_PAY_PREFIX_ALI + paymentParam.getOrderId() );
            } else {
                payVo.setP2_orderId(HLB_PAY_PREFIX_ALI + paymentParam.getOrderId() + HLB_MOD_PAY_SUFFIX + paymentParam.getModifyIndex());
            }
        }
        // 追加
        if(paymentParam.getAddType() == 1) {
            payVo.setP2_orderId(HLB_PAY_PREFIX_ALI + paymentParam.getOrderId() + HLB_ADD_PAY_SUFFIX + paymentParam.getAddCountIndex());
        }
        payVo.setP3_customerNumber(customerNumber);
        payVo.setP4_payType("SCAN");
//        if (billInfo.getMarketingAmount() != null) {
//            payVo.setP5_orderAmount(billInfo.getOrderAmount().add(billInfo.getMarketingAmount()).toString());
//        } else {
//            payVo.setP5_orderAmount(billInfo.getOrderAmount().toString());
//        }
        payVo.setP5_orderAmount(billInfo.getOrderAmount().toString());
        payVo.setP6_currency("CNY");
        payVo.setP7_authcode("1");
        payVo.setP8_appType("ALIPAY");
        payVo.setP11_orderIp("127.0.0.1");
//        payVo.setP10_successToUrl("ALIPAY");
        payVo.setP13_goodsDetail("家政服务订单");
        payVo.setP14_desc("用户付款");
        Map<String, String> map = null;
        try {
            map = BeanUtils.convertBean(payVo, new LinkedHashMap());
        } catch (IntrospectionException e) {
            e.printStackTrace();
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        } catch (InvocationTargetException e) {
            e.printStackTrace();
        }
        String oriMessage = BeanUtils.getSignedByPresetParameter(map, SDKCreateOrderVo.NEED_SIGN_PARAMS);
        log.info("签名原文串：" + oriMessage);
        String sign = Disguiser.disguiseMD5(oriMessage.trim());
        log.info("签名串：" + sign);
        map.put("sign", sign);
        log.info("发送参数：" + map);
        Map<String, Object> resultMap = HttpClientService.getHttpResp(map, HeliPayContants.PAY_REQUEST_URL);
        return resultMap;
    }

    /**
     * 支付宝SDK预支付
     *
     * @param param  支付参数
     * @param openId 微信openId，仅仅微信支付使用，其他传Null
     * @return
     */
    @Override
    public Map<String, Object> hlbPay(PaymentParam param, String openId) {
        BillInfo billInfo = new BillInfo();
        // 判断业务类型(是否是 0商家  1是个人)
        if (param.getMerchantType().equals(1)) {

            billInfo.setOrderAmount(param.getTotalAmount());
            if (StringUtils.isEmpty(openId)) {
                // 支付宝SDK支付
                return aliSdkPay(param, billInfo);
            } else {
                // 微信小程序支付
                billInfo.setOpenId(openId);
                return wxAppletPay(param, billInfo);
            }
        } else {
            billInfo.setOrderAmount(param.getTotalAmount());
            //商家类型为商家的

            //商家可得金额
            BigDecimal splitAmount = param.getShopAmount();
            //总营销金额
            BigDecimal marketingAmount = param.getTotalAmount();
            //商家邮箱
            String email = param.getEmail();

            //分账信息
            List<SplitBillInfo> splitBillInfos = new ArrayList<>();
            SplitBillInfo splitBillInfo = SplitBillInfo.builder()
                    .splitBillMerchantEmail(email).splitBillAmount(splitAmount).build();
            splitBillInfos.add(splitBillInfo);
            billInfo.setSplitBillRule(JSON.toJSONString(splitBillInfos));
            log.info("合利宝预支付 -- 分账规则字符串：" + billInfo.getSplitBillRule());
            if (marketingAmount.compareTo(BigDecimal.ZERO) > 0) {
                billInfo.setMarketingAmount(marketingAmount);
                log.info("合利宝预支付 -- 营销规则字符串：" + billInfo.getMarketingRuleStr());
            }

            // 是否使用平台优惠券（营销补贴）
              // 总营销金额
            if (StringUtils.isEmpty(openId)) {
                // 支付宝SDK支付
                return aliSdkPay(param, billInfo);
            } else {
                // 微信小程序支付
                billInfo.setOpenId(openId);
                return wxAppletPay(param, billInfo);
            }
        }
    }

    /**
     * 全额退款
     * 三方配送且骑手已接单，会扣除运费
     *
     * @param orderId 订单ID
     * @return 成功与否
     */
    @Override
    public boolean orderRefund(String orderId, String merchantEmail, BigDecimal amount, BigDecimal shopAmount, String payWay, boolean isSplitBill){
        AppPayRefundOrderVo vo = new AppPayRefundOrderVo();
        // 交易类型
        vo.setP1_bizType("AppPayRefund");
        // 商户订单号
        if ("001".equals(payWay)) {
            vo.setP2_orderId(HLB_PAY_PREFIX_WX + orderId);
        } else {
            vo.setP2_orderId(HLB_PAY_PREFIX_ALI + orderId);
        }
        // 商户编号
        vo.setP3_customerNumber(MAIN_CUSTOMER_NUMBER);
        // 退款订单号
        vo.setP4_refundOrderId(orderId + System.currentTimeMillis());
        // 退款金额
        vo.setP5_amount(amount.toString());
        // 通知回调地址
        vo.setP6_callbackUrl(refundCbUrl);
        // 退款原因/备注
        vo.setP7_desc("用户全额退款");
        // 退款规则串 (未分账的订单不需要传此参数)
        if (isSplitBill) {
            List<RefundSplitBillInfo> refundSplitBillInfos = new ArrayList<>();
            RefundSplitBillInfo mainSplitBillInfo = RefundSplitBillInfo.builder()
                    .splitBillMerchantEmail(MAIN_CUSTOMER_MAIL).refundAmount(amount.subtract(shopAmount)).build();
            refundSplitBillInfos.add(mainSplitBillInfo);
            RefundSplitBillInfo splitBillInfo = RefundSplitBillInfo.builder()
                    .splitBillMerchantEmail(merchantEmail).refundAmount(shopAmount).build();
            refundSplitBillInfos.add(splitBillInfo);
            String rule = JSON.toJSONString(refundSplitBillInfos);
            log.info("退款分账规则字符串：" + rule);
            vo.setRuleJson(rule);
        }

        return refund(vo);
    }

    @Override
    public boolean cancelOrder(String orderId) {
        AppPayCloseOrderVo vo = new AppPayCloseOrderVo();
        vo.setP1_bizType("AppPayClose");
        vo.setP2_orderId(orderId);
        vo.setP3_customerNumber(MAIN_CUSTOMER_NUMBER);
        Map<String, String> map = null;
        try {
            map = BeanUtils.convertBean(vo, new LinkedHashMap());
        } catch (IntrospectionException e) {
            e.printStackTrace();
            return false;
        } catch (IllegalAccessException e) {
            e.printStackTrace();
            return false;
        } catch (InvocationTargetException e) {
            e.printStackTrace();
            return false;
        }
        String oriMessage = BeanUtils.getSignedByPresetParameter(map, AppPayCloseOrderVo.NEED_SIGN_PARAMS);
        log.info("签名原文串：" + oriMessage);
        String sign = Disguiser.disguiseMD5(oriMessage.trim());
        log.info("签名串：" + sign);
        map.put("sign", sign);
        log.info("发送参数：" + map);
        Map<String, Object> resultMap = HttpClientService.getHttpResp(map, HeliPayContants.PAY_REQUEST_URL);
        if ((Integer) resultMap.get("statusCode") == HttpStatus.SC_OK) {
            String resultMsg = (String) resultMap.get("response");
            AppPayCloseResponseVo orderResponseVo = JSONObject.parseObject(resultMsg, AppPayCloseResponseVo.class);
            //String[] excludes = {"rt3_retMsg"};
            String assemblyRespOriSign = null;
            try {
                assemblyRespOriSign = BeanUtils.getSignedByPresetParameter(orderResponseVo, AppPayCloseResponseVo.NEED_SIGN_PARAMS);
            } catch (IllegalAccessException e) {
                e.printStackTrace();
                return false;
            } catch (IntrospectionException e) {
                e.printStackTrace();
                return false;
            } catch (InvocationTargetException e) {
                e.printStackTrace();
                return false;
            }
            log.info("组装返回结果签名串：" + assemblyRespOriSign);
            String responseSign = orderResponseVo.getSign();
            log.info("响应签名：" + responseSign);
            String checkSign = Disguiser.disguiseMD5(assemblyRespOriSign.trim());
            if (checkSign.equals(responseSign)) {
                if ("0000".equals(orderResponseVo.getRt2_retCode())) {
                    return true;
                } else {
                    return false;
                }
            } else {
                return false;
            }
        } else {
            return false;
        }
    }

    /**
     * 创建主动扫码二维码
     *
     * @param orderId 商户订单号
     * @param orderAmount 交易金额
     */
    @Override
    public String createScanOrder(String orderId, BigDecimal orderAmount) {
        AppCreateOrderVo orderVo = new AppCreateOrderVo();
        orderVo.setP1_bizType("AppPay");
        orderVo.setP2_orderId(orderId);
        orderVo.setP3_customerNumber(MAIN_CUSTOMER_NUMBER);
        orderVo.setP4_payType("SCAN");
        orderVo.setP5_orderAmount(orderAmount.toString());
        orderVo.setP6_currency("CNY");
        orderVo.setP7_authcode("1");
        orderVo.setP8_appType("ALIPAY");
        orderVo.setP9_notifyUrl(hlbScanPayCbUrl);
        orderVo.setP10_successToUrl(hlbScanPayCbSuccessUrl);
        orderVo.setP11_orderIp("127.0.0.1");
        orderVo.setP12_goodsName("保证金支付");
        try {
            Map<String, String> map = BeanUtils.convertBean(orderVo, new LinkedHashMap());
            String oriMessage = BeanUtils.getSignedByPresetParameter(map, AppCreateOrderVo.NEED_SIGN_PARAMS);
            log.info("主动签名原文串：" + oriMessage);
            String sign = Disguiser.disguiseMD5(oriMessage.trim());
            log.info("主动签名串：" + sign);
            map.put("sign", sign);
            log.info("主动发送参数：" + map);
            Map<String, Object> resultMap = HttpClientService.getHttpResp(map, HeliPayContants.PAY_REQUEST_URL);
            log.info("响应结果：" + resultMap);
            if ((Integer) resultMap.get("statusCode") == HttpStatus.SC_OK) {
                String resultMsg = (String) resultMap.get("response");
                AppCreateOrderResponseVo orderResponseVo = JSONObject.parseObject(resultMsg, AppCreateOrderResponseVo.class);
                String assemblyRespOriSign = BeanUtils.getSignedByPresetParameter(orderResponseVo, AppCreateOrderResponseVo.NEED_SIGN_PARAMS);
                log.info("主动组装返回结果签名串：" + assemblyRespOriSign);
                String responseSign = orderResponseVo.getSign();
                log.info("主动响应签名：" + responseSign);
                String checkSign = Disguiser.disguiseMD5(assemblyRespOriSign.trim());
                if (checkSign.equals(responseSign)) {
                    if ("0000".equals(orderResponseVo.getRt2_retCode())) {
                        JSONObject jsonObject = JSONObject.parseObject(resultMsg);
                        log.info("主扫下单成功" );
                        return jsonObject.getString("rt8_qrcode");
                    } else {
                        log.error("主扫下单失败" + orderResponseVo.getRt5_orderId() + "-" + orderResponseVo.getRt3_retMsg() );
                        return null;
                    }
                }
            }
        } catch (IntrospectionException e) {
            e.printStackTrace();
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        } catch (InvocationTargetException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 合利宝退款服务
     */
    private boolean refund(AppPayRefundOrderVo vo){
        try {
            Map<String, String> map = BeanUtils.convertBean(vo, new LinkedHashMap());
            String oriMessage = BeanUtils.getSignedByPresetParameter(map, AppPayRefundOrderVo.NEED_SIGN_PARAMS);
            log.info("签名原文串：" + oriMessage);
            String sign = Disguiser.disguiseMD5(oriMessage.trim());
            log.info("签名串：" + sign);
            map.put("sign", sign);
            log.info("发送参数：" + map);
            Map<String, Object> resultMap = HttpClientService.getHttpResp(map, HeliPayContants.PAY_REQUEST_URL);
            log.info("响应结果：" + resultMap);
            if ((Integer) resultMap.get("statusCode") == HttpStatus.SC_OK) {
                String resultMsg = (String) resultMap.get("response");
                AppPayRefundOrderResponseVo orderResponseVo = JSONObject.parseObject(resultMsg, AppPayRefundOrderResponseVo.class);
                log.info("订单退款返回结果对象orderResponseVo: " + JSON.toJSONString(orderResponseVo));
                String assemblyRespOriSign = BeanUtils.getSignedByPresetParameter(orderResponseVo, AppPayRefundOrderResponseVo.NEED_SIGN_PARAMS);
                log.info("组装返回结果签名串：" + assemblyRespOriSign);
                String responseSign = orderResponseVo.getSign();
                log.info("响应签名：" + responseSign);
                String checkSign = Disguiser.disguiseMD5(assemblyRespOriSign.trim());
                if (checkSign.equals(responseSign)) {
                    if ("0001".equals(orderResponseVo.getRt2_retCode())) {
                        // 退款申请成功
                        log.info("退款申请成功 " + orderResponseVo.getRt5_orderId());
                        return true;
                    } else {
                        // TODO 退款失败，将请求存在记录表中
                        throw new RuntimeException("订单退款失败 -- " + orderResponseVo.getRt3_retMsg());
                    }
                } else {
                    // TODO 退款失败，将请求存在记录表中
                    throw new RuntimeException("退款申请失败：" + orderResponseVo.getRt3_retMsg());
                }
            } else {
                // TODO 退款失败，将请求存在Redis中，待处理
//                recordMsg(vo.getP2_orderId().split("-")[1], oriMessage, JSON.toJSONString(resultMap));
                throw new RuntimeException("退款申请失败：" + resultMap.get("statusCode"));
            }
        } catch (Exception e) {
            // TODO 退款失败，将请求存在Redis中，待处理
//            recordMsg(vo.getP2_orderId().split("-")[1], JSON.toJSONString(vo), "");
            throw new RuntimeException("退款申请失败：" + e.getMessage());
        }
    }
}
