package com.younike.system.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.younike.common.annotation.Excel;
import com.younike.common.core.domain.BaseEntity;
import lombok.Data;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * 店铺信息对象 merchant
 *
 * @author elev
 * @date 2022-01-07
 */
@Data
public class Merchant extends BaseEntity{
    private static final long serialVersionUID = 1L;

    /** 商户ID */
    private Long merchantId;

    /** 商户用户Id（sys_user主键） */
    @Excel(name = "商户用户Id", readConverterExp = "s=ys_user主键")
    private Long adminId;

    /** 0商家 1个人 */
    @Excel(name = "0商家 1个人")
    private Integer merchantType;

    /** 商家编号(商家:SJ开头;个体户:GT开头;) */
    @Excel(name = "商家编号")
    private String merchantIndex;

    /** 商户名称 */
    @Excel(name = "商户名称")
    private String merchantName;

    /** 商户介绍 */
    @Excel(name = "商户介绍")
    private String merchantDesc;

    /** 商户电话 */
    @Excel(name = "商户电话")
    private String merchantPhone;

    /** 客服电话（默认和商户电话一致） */
    @Excel(name = "客服电话", readConverterExp = "默=认和商户电话一致")
    private String serverPhone;

    /** 店龄 */
    @Excel(name = "店龄")
    private BigDecimal storeAge;

    /** 省 */
    @Excel(name = "省")
    private Integer provinceId;

    /** 市 */
    @Excel(name = "市")
    private Integer cityId;

    /** 区 */
    @Excel(name = "区")
    private Integer areaId;

    /** 头像 */
    @Excel(name = "头像")
    private String avatar;

    /** 详细地址 */
    @Excel(name = "详细地址")
    private String detail;

    /** 门牌号 */
    @Excel(name = "门牌号")
    private String houseNumber;

    /** 经度 */
    @Excel(name = "经度")
    private BigDecimal longitude;

    /** 纬度 */
    @Excel(name = "纬度")
    private BigDecimal latitude;

    /** 微信服务商ID */
    @Excel(name = "微信服务商ID")
    private String wxServiceId;

    /** 阿里云服务商ID */
    @Excel(name = "阿里云服务商ID")
    private String aliServiceId;

    /** 保证金 */
    @Excel(name = "保证金")
    private BigDecimal bondMoney;

    /** 商家评分 */
    @Excel(name = "商家评分")
    private BigDecimal score;

    /** 服务范围（半径） */
    @Excel(name = "服务范围", readConverterExp = "半=径")
    private BigDecimal serviceDistance;

    /** 订单总金额是否显示(0:显示;1:显示; */
    private Integer orderTotalAmountShow;

    /** 好评率 */
    @Excel(name = "好评率")
    private BigDecimal rate;

    /** 店铺状态 code 001审核中 002审核成功 003审核失败 004店铺下架 */
    @Excel(name = "店铺状态 code")
    private String shopState;

    /** 审核人 */
    @Excel(name = "审核人")
    private Long examineUser;

    /** 成交量（定时任务统计结果） */
    @Excel(name = "成交量", readConverterExp = "定=时任务统计结果")
    private Integer sales;

    /** 审核失败原因 */
    @Excel(name = "审核失败原因")
    private String examineReason;

    /** 审核时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "审核时间", width = 30, dateFormat = "yyyy-MM-dd")
    private LocalDateTime examineTime;

    /** 店铺关闭人 */
    @Excel(name = "店铺关闭人")
    private Long closeUser;

    /** 关店原因 */
    @Excel(name = "关店原因")
    private String closeReason;

    /** 关店时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "关店时间", width = 30, dateFormat = "yyyy-MM-dd")
    private LocalDateTime closeTime;

    /** 店铺推广人手机 */
    @Excel(name = "店铺推广人手机")
    private String promoter;

    /** 营业状态 code 营业状态001营业中 002停止营业  */
    @Excel(name = "营业状态 code ")
    private String businessState;

    /** 分账比例 */
    @Excel(name = "分账比例")
    private String commissionRate;

    /** 删除标志（0代表存在 2代表删除） */
    private String delFlag;

    /** 最后登录IP */
    @Excel(name = "最后登录IP")
    private String loginIp;

    /** 最后登录时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "最后登录时间", width = 30, dateFormat = "yyyy-MM-dd")
    private LocalDateTime loginDate;

    /** 预留字段1 */
    @Excel(name = "预留字段1")
    private String column1;

    /** 预留字段2 */
    @Excel(name = "预留字段2")
    private String column2;

    /**
     * 预留字段2
     */
    @Excel(name = "预留字段2")
    private String column3;

    private Integer allowCompose;

    /**
     * 店铺banner图片url
     */
    @Excel(name = "店铺banner图片url")
    private String bannerImgUrl;

    private Integer agentId;
}
