package com.younike.system.mapper;

import java.util.List;
import com.younike.system.domain.Category;
import com.younike.system.domain.vo.CategoryVo;
import org.apache.ibatis.annotations.Param;

/**
 * 分类Mapper接口
 *
 * @author elev
 * @date 2022-01-04
 */
public interface CategoryMapper {

    /**
     * 获取分类列表及评价维度列表
     * @return
     */
    List<CategoryVo> getCategoryList(@Param("bizType") Integer bizType);

    /**
     *
     * @param parentId
     * @return
     */
    List<Category> getByParentId(@Param("parentId") String parentId);

    /**
     * 查询分类
     *
     * @param categoryId 分类主键
     * @return 分类
     */
    Category selectCategoryByCategoryId(Long categoryId);

    /**
     * 查询分类列表
     *
     * @param category 分类
     * @return 分类集合
     */
    List<Category> selectCategoryList(Category category);

    /**
     * 批量更新排序
     * @param categoryList
     * @return
     */
    int updateSortingBatch(@Param("categoryList") List<Category> categoryList);

    /**
     * 新增分类
     *
     * @param category 分类
     * @return 结果
     */
    int insertCategory(Category category);

    /**
     * 修改分类
     *
     * @param category 分类
     * @return 结果
     */
    int updateCategory(Category category);

    /**
     * 删除分类
     *
     * @param categoryId 分类主键
     * @return 结果
     */
    int deleteCategoryByCategoryId(Long categoryId);

    /**
     * 批量删除分类
     *
     * @param categoryIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCategoryByCategoryIds(Long[] categoryIds);

    /**
     * 获取首页商品分类数据
     * @return
     */
    List<CategoryVo> selectCategoriesList(@Param("bizType") Integer bizType);

    /**
     * 首页服务数据
     * @return
     */
    List<Category> getHomeCategoriesList(@Param("bizType") Integer bizType);

    Category selectCategoryByGoodsId(Long goodsId);

    /**
     * （服务端）查询全部一级分类
     * @return
     */
    List<Category> selectCategoriesPublishList();

    List<Category> serverCategoryList(@Param("merchantId") Long merchantId);
}
