package com.younike.system.mapper;

import com.younike.system.domain.Publish;
import com.younike.system.domain.vo.PublishManageVo;
import com.younike.system.param.PublishQueryParam;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 发布需求Mapper接口
 *
 * @author elev
 * @date 2022-01-20
 */
public interface PublishMapper {

    /**
     * 获取任务列表，商家端，运营端
     * @param param
     * @return
     */
    List<PublishManageVo> publishManageList(PublishQueryParam param);

    /**
     * 删除任务
     * @param publishId
     * @return
     */
    int deleteByPublishId(Long publishId);

    /**
     * 查询发布需求
     *
     * @param publishId 发布需求主键
     * @return 发布需求
     */
    Publish selectPublishByPublishId(Long publishId);

    /**
     * 查询发布需求列表
     *
     * @param publish 发布需求
     * @return 发布需求集合
     */
    List<Publish> selectPublishList(Publish publish);

    /**
     * 新增发布需求
     *
     * @param publish 发布需求
     * @return 结果
     */
    int insertPublish(Publish publish);

    /**
     * 修改发布需求
     *
     * @param publish 发布需求
     * @return 结果
     */
    int updatePublish(Publish publish);

    /**
     * 删除发布需求
     *
     * @param publishId 发布需求主键
     * @return 结果
     */
    int deletePublishByPublishId(Long publishId);

    /**
     * 批量删除发布需求
     *
     * @param publishIds 需要删除的数据主键集合
     * @return 结果
     */
    int deletePublishByPublishIds(Long[] publishIds);

    /**
     * 查询我发布需求列表
     * @param param
     * @return
     */
    List<PublishManageVo> mePublishList(PublishQueryParam param);

    /**
     * 需求详情（包含地址信息）
     */
    PublishManageVo getPublishByPublishId(Long publishId);

    /**
     * 查询我发布需求条数
     * @param memberId
     * @return
     */
    List<Publish> mePublishCount(Long memberId);

    /**
     * 服务端查询任务广场列表
     * @param param
     * @return
     */
    List<PublishManageVo> publishServerList(PublishQueryParam param);

    /**
     * 服务端查询任务广场我报价的需求列表
     * @param param
     * @return
     */
    List<PublishManageVo> quoteList(PublishQueryParam param);

    /**
     * （服务人员） 获取发布需求详细信息
     * @param param
     * @return
     */
    PublishManageVo selectPublishBy(PublishQueryParam param);

    /**
     * 取消订单（发布需求的订单）
     * @param publish
     * @return
     */
    int  cancelPublishOrder(Publish publish);

    /**
     * 查询任务广场入口数据
     * @param param
     * @return
     */
    List<PublishManageVo> taskList(PublishQueryParam param);

    /**
     * 查询发布需求详细信息
     *
     * @param publishId
     * @return
     */
    PublishManageVo getPublishDetail(@Param("publishId") Long publishId);
}
