package com.younike.system.service;

import java.util.List;

import com.younike.common.core.domain.AjaxResult;
import com.younike.system.domain.Category;
import com.younike.system.domain.vo.CategoryVo;

/**
 * 分类Service接口
 *
 * @author elev
 * @date 2022-01-04
 */
public interface ICategoryService {
    /**
     * 分类新增/修改
     * @param categoryVo
     * @return
     */
    AjaxResult submit(CategoryVo categoryVo);

    /**
     * 分类新增/修改
     * @param category
     * @return
     */
    AjaxResult submitChild(Category category);

    /**
     * 获取分类列表
     * @return
     */
    List<CategoryVo> categoryList(Integer bizType);

    /**
     * 获取启用的分类列表
     * @return
     */
    List<CategoryVo> enabledCategoryList(Integer bizType);

    /**
     * 分类树
     * @return
     */
    List<CategoryVo> categoryTree();

    /**
     * 批量更新排序
     * @param categoryList
     * @return
     */
    int updateSortingBatch(List<Category> categoryList);

    /**
     * 查询分类
     *
     * @param categoryId 分类主键
     * @return 分类
     */
    Category selectCategoryByCategoryId(Long categoryId);

    /**
     * 查询分类列表
     *
     * @param category 分类
     * @return 分类集合
     */
    List<Category> selectCategoryList(Category category);

    /**
     * 新增分类
     *
     * @param category 分类
     * @return 结果
     */
    int insertCategory(Category category);

    /**
     * 修改分类
     *
     * @param category 分类
     * @return 结果
     */
    int updateCategory(Category category);

    /**
     * 批量删除分类
     *
     * @param categoryIds 需要删除的分类主键集合
     * @return 结果
     */
    int deleteCategoryByCategoryIds(Long[] categoryIds);

    /**
     * 删除分类信息
     *
     * @param categoryId 分类主键
     * @return 结果
     */
    int deleteCategoryByCategoryId(Long categoryId);

    /**
     * 全部服务数据
     * @return
     */
    AjaxResult selectCategoriesList(Integer bizType);

    /**
     * 首页服务数据
     * @return
     */
    List<CategoryVo> getHomeCategoriesList(Integer bizType);

    AjaxResult selectCategoriesListServer(Integer bizType);

    Category selectCategoryByGoodsId(Long goodsId);

    /**
     * （服务端）查询全部一级分类
     * @return
     */
    AjaxResult categoriesPublishList( Long serverId);

    /**
     * 查询所有一级分类
     * @return
     */
    List<Category> categoriesPublishIdList();

    /**
     * 首页服务分类（包含分类下数据）数据
     * @param bizType
     * @param goodsType 商家 0，预定 1，团购 2
     * @return
     */
    AjaxResult getHomeCategoriesCountList(Integer bizType, Integer goodsType);

    /**
     * 根据服务人员id获取所在商家的分类列表
     * @param serverId
     * @return
     */
    AjaxResult serverCategoryList(Long serverId);
}
