package com.younike.system.service;

import com.younike.common.core.domain.AjaxResult;
import com.younike.system.domain.MemberAddress;
import com.younike.system.domain.vo.MemberAddressVo;
import com.younike.system.param.MemberAddressParam;

import java.util.List;

/**
 * 会员服务地址Service接口
 *
 * @author elev
 * @date 2022-01-04
 */
public interface IMemberAddressService
{
    /**
     * 查询会员服务地址
     *
     * @param addressId 会员服务地址主键
     * @return 会员服务地址
     */
    public MemberAddress selectMemberAddressByAddressId(Long addressId);

    /**
     * 查询会员服务地址列表
     *
     * @param memberAddress 会员服务地址
     * @return 会员服务地址集合
     */
    public List<MemberAddress> selectMemberAddressList(MemberAddress memberAddress);

    /**
     * 新增会员服务地址
     *
     * @param memberAddress 会员服务地址
     * @return 结果
     */
    public int insertMemberAddress(MemberAddress memberAddress);

    /**
     * 修改会员服务地址
     *
     * @param memberAddress 会员服务地址
     * @return 结果
     */
    public int updateMemberAddress(MemberAddress memberAddress);

    /**
     * 批量删除会员服务地址
     *
     * @param addressIds 需要删除的会员服务地址主键集合
     * @return 结果
     */
    public int deleteMemberAddressByAddressIds(Long[] addressIds);

    /**
     * 删除会员服务地址信息
     *
     * @param addressId 会员服务地址主键
     * @return 结果
     */
    public int deleteMemberAddressByAddressId(Long addressId);

    /**
     * 获取会员地址列表
     * @param memberAddress
     * @return
     */
    AjaxResult getAddressList(MemberAddressParam memberAddress);


}

