package com.younike.system.service;

import com.younike.system.domain.vo.GoodsCommentsVO;
import com.younike.system.param.GoodsCommentQueryParam;

import java.util.List;

/**
 * 商品评价Service接口
 *
 * @author jubs
 * @date 2022-01-11
 */
public interface IMerchantGoodsCommentService {
    /**
     * 查询商品评价
     *
     * @param commontId 商品评价主键
     * @return 商品评价
     */
    GoodsCommentsVO selectGoodsCommentByCommontId(Long commontId);

    /**
     * 查询商品评价列表
     *
     * @param goodsCommentsVO 商品评价
     * @return 商品评价集合
     */
    List<GoodsCommentsVO> selectGoodsCommentList(GoodsCommentsVO goodsCommentsVO);

    /**
     * 新增商品评价
     *
     * @param goodsComment 商品评价
     * @return 结果
     */
    int insertGoodsComment(GoodsCommentsVO goodsComment);

    /**
     * 修改商品评价
     *
     * @param goodsComment 商品评价
     * @return 结果
     */
    int updateGoodsComment(GoodsCommentsVO goodsComment);

    /**
     * 批量删除商品评价
     *
     * @param commontIds 需要删除的商品评价主键集合
     * @return 结果
     */
    int deleteGoodsCommentByCommontIds(Long[] commontIds);

    /**
     * 删除商品评价信息
     *
     * @param commontId 商品评价主键
     * @return 结果
     */
    int deleteGoodsCommentByCommontId(Long commontId);

    /**
     * 根据订单类型查询订单商品评价列表
     *
     * @param commentQueryParam
     * @return
     */
    List<GoodsCommentsVO> listGoodsCommentByOrderType(GoodsCommentQueryParam commentQueryParam);
}
