package com.younike.system.service;

import com.younike.common.core.domain.AjaxResult;
import com.younike.system.domain.Publish;
import com.younike.system.domain.vo.PublishManageVo;
import com.younike.system.domain.vo.PublishUpdateVo;
import com.younike.system.param.PublishQueryParam;

import java.util.List;

/**
 * 发布需求Service接口
 *
 * @author elev
 * @date 2022-01-20
 */
public interface IPublishService {

    /**
     * 运营端端发布列表
     * @param param
     * @return
     */
    List<PublishManageVo> publishAdminList(PublishQueryParam param);

    /**
     * 删除任务
     * @param publishId
     * @return
     */
    AjaxResult deleteByPublishId(Long publishId);

    /**
     * 新增任务
     * @param publish
     * @return
     */
    AjaxResult publishInsert(PublishUpdateVo publish);

    /**
     * 商家端发布广场列表
     * @param param
     * @return
     */
    List<PublishManageVo> publishManageList(PublishQueryParam param);

    /**
     * 查询发布需求
     *
     * @param publishId 发布需求主键
     * @return 发布需求
     */
    Publish selectPublishByPublishId(Long publishId);

    /**
     * 查询发布需求列表
     *
     * @param publish 发布需求
     * @return 发布需求集合
     */
    List<Publish> selectPublishList(Publish publish);

    /**
     * 新增发布需求
     *
     * @param publish 发布需求
     * @return 结果
     */
    int insertPublish(Publish publish);

    /**
     * 修改发布需求
     *
     * @param publish 发布需求
     * @return 结果
     */
    int updatePublish(Publish publish);

    /**
     * 批量删除发布需求
     *
     * @param publishIds 需要删除的发布需求主键集合
     * @return 结果
     */
    int deletePublishByPublishIds(Long[] publishIds);

    /**
     * 删除发布需求信息
     *
     * @param publishId 发布需求主键
     * @return 结果
     */
    int deletePublishByPublishId(Long publishId);

    /**
     * 查询我发布需求列表
     * @param param
     * @return
     */
    List<PublishManageVo> mePublishList(PublishQueryParam param);

    /**
     * 下架需求
     * @param publishId
     * @return
     */
    AjaxResult soldOut(Long publishId);

    /**
     * 上架
     * @param publishId
     * @return
     */
    AjaxResult putaway(Long publishId);

    /**
     * 获取发布需求详细信息(包含地址信息)
     * @param publishId
     * @return
     */
    AjaxResult getPublishByPublishId(Long publishId);

    /**
     * 编辑需求
     * @param publish
     * @return
     */
    AjaxResult editPublish(PublishUpdateVo publish);

    /**
     * 查询我发布需求条数
     * @param memberId
     * @return
     */
    AjaxResult mePublishCount(Long memberId);

    /**
     * 服务端查询任务广场列表
     * @param param
     * @return
     */
    List<PublishManageVo> publishServerList(PublishQueryParam param);

    /**
     * 服务端查询任务广场我报价的需求列表
     * @param param
     * @return
     */
    List<PublishManageVo> publishList(PublishQueryParam param);

    /**
     * （服务人员） 获取发布需求详细信息
     * @param param
     * @return
     */
    AjaxResult selectPublishBy(PublishQueryParam param);

    /**
     * 订单变更  （任务状态变更）
     * 如果是未付款则任务回到未指派状态  商品进行逻辑删除
     * 如果服务人员未开始服务则任务回到未指派状态  商品进行逻辑删除
     * 根据订单号查询，判断服务人员是否开始服务，
     * 如果服务人员已经开始服务则任务完成，
     * 如果订单已经完成则任务完成
     * @param orderId
     * @return
     */
    Boolean cancelPublishOrder(Long orderId);


    /**
     * 查询任务广场入口数据
     * @param param
     * @return
     */
    List<PublishManageVo> taskList(PublishQueryParam param);

    /**
     * 查询发布需求详细信息
     *
     * @param publishId
     * @return
     */
    AjaxResult getPublishDetail(Long publishId);
}
