package com.younike.system.service.impl;

import com.younike.system.domain.ServerTimeSection;
import com.younike.system.domain.vo.MerchantServerTimeSectionVo;
import com.younike.system.mapper.MerchantServerTimeSectionMapper;
import com.younike.system.service.IMerchantServerTimeSectionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

/**
 * 服务人员服务时间段Service业务层处理
 *
 * @author elev
 * @date 2022-01-13
 */
@Service
public class MerchantServerTimeSectionServiceImpl implements IMerchantServerTimeSectionService {
    @Autowired
    private MerchantServerTimeSectionMapper serverTimeSectionMapper;

    /**
     * 查询服务人员服务时间段
     *
     * @param sectionId 服务人员服务时间段主键
     * @return 服务人员服务时间段
     */
    @Override
    public MerchantServerTimeSectionVo selectServerTimeSectionBySectionId(String sectionId) {
        return serverTimeSectionMapper.selectServerTimeSectionBySectionId(sectionId);
    }

    /**
     * 查询服务人员服务时间段列表
     *
     * @param serverTimeSection 服务人员服务时间段
     * @return 服务人员服务时间段
     */
    @Override
    public List<MerchantServerTimeSectionVo> selectServerTimeSectionList(MerchantServerTimeSectionVo serverTimeSection) {
        return serverTimeSectionMapper.selectServerTimeSectionList(serverTimeSection);
    }

    /**
     * 新增服务人员服务时间段
     *
     * @param serverTimeSection 服务人员服务时间段
     * @return 结果
     */
    @Override
    public int insertServerTimeSection(MerchantServerTimeSectionVo serverTimeSection) {
//        serverTimeSection.setCreateTime(LocalDateTime.now());
        return serverTimeSectionMapper.insertServerTimeSection(serverTimeSection);
    }

    /**
     * 修改服务人员服务时间段
     *
     * @param serverTimeSection 服务人员服务时间段
     * @return 结果
     */
    @Override
    public int updateServerTimeSection(MerchantServerTimeSectionVo serverTimeSection) {
//        serverTimeSection.setUpdateTime(LocalDateTime.now());
        return serverTimeSectionMapper.updateServerTimeSection(serverTimeSection);
    }

    /**
     * 批量删除服务人员服务时间段
     *
     * @param sectionIds 需要删除的服务人员服务时间段主键
     * @return 结果
     */
    @Override
    public int deleteServerTimeSectionBySectionIds(String[] sectionIds) {
        return serverTimeSectionMapper.deleteServerTimeSectionBySectionIds(sectionIds);
    }

    /**
     * 删除服务人员服务时间段信息
     *
     * @param sectionId 服务人员服务时间段主键
     * @return 结果
     */
    @Override
    public int deleteServerTimeSectionBySectionId(String sectionId)
    {
        return serverTimeSectionMapper.deleteServerTimeSectionBySectionId(sectionId);
    }
}
